# == Schema Information
#
# Table name: languages
#
#  id         :integer          not null, primary key
#  user_id    :integer
#  code       :string(5)
#  name       :string(50)
#  local_name :string(50)
#  region     :string(50)
#  suggestion :boolean
#  state      :string(50)       default("suggesiton")
#  active     :boolean          default(FALSE)
#  created_at :datetime
#  updated_at :datetime
#
module Xforum
  class Language < ActiveRecord::Base
    require 'json'

    has_many :translations, dependent: :destroy

    def self.toggle_language(params,user)  #this has to be an all new  language
      state= Language.where(name:params[:language]).pluck(:active)[0]
      Language.where(name:params[:language]).update_all(active:!state) if user.forum_admin?
      {action:'nothing to do'}
    end

    def self.add_language(params,user)
      if user.forum_admin?
         Language.create(code:params[:code],name:params[:name],local_name:params[:local])
      end
    end

    def self.languages(params)
      if ENV['XFORUM_LANGUAGES'].nil?
        alist=[]
      elsif Language.first.nil?
        Language.init_language_set
        Language.load_env_set
      else
        Language.load_env_set
        params[:active] == 'true' ?
          alist=Language.where(active:true).order(:code).pluck(:id,:name,:code,:local_name,:active)  :
          alist=Language.where(active:false).order(:code).pluck(:id,:name,:code,:local_name,:active)
        unless alist.empty?
          alist=ForumAssist.named_array(alist,[:id,:item,:value,:local_name,:state])
          alist=Translation.translate_list(alist,'','language')
        end
        alist.unshift({value: I18n.t('xForum.select_language'),item: I18n.t('xForum.select_language') ,state:'open',id:0}) unless params[:short]
        {list_data:alist,id:params[:list]}
      end
    end

    def self.load_env_set
      set=ENV['XFORUM_LANGUAGES'].split(';')
      set.each {|code|
        Language.where(code:code).update_all(active:true)
      }

    end
    def self.get_suggestions(params,user)
      if user.forum_admin?
        data= Language.where(suggestion:true).pluck(:name, :user_id, :id)
        data=ForumAssist.named_array(data, [:suggestion, :user,:id ]) unless data.empty?
        data=ForumAssist.add_user_name(data.clone) unless data.empty?
        {data:data,list:'forum-language-prososals-list'}
      else
        {reply:'nothing doing'}
      end
    end

    def self.suggestion(params,user)  #add new category or topic
      Language.create(suggestion:true,content:params[:suggestion],user_id:user.id,hold:true)
      {response:'nothing to do'}
    end

    def self.suggestion_close(params,user)
      params[:result]=='Accept' ?
          (Language.where(id: params[:id]).update_all(suggestion: false) if user.forum_admin?) :
          Language.where(id: params[:id]).update_all(state: 'closed') if user.forum_admin?
    end
    def self.get_language_locale(params)
      params[:language].nil? ? id= Language.where(code:I18n.locale.to_s).pluck(:id)[0]  : id=Language.get_me(params)
      id.nil? ? Language.first.id : id
    end
    def self.get_me(params)
      return if params[:language].nil?
      params[:language] = params[:language][0] if params[:language].is_a?(Array)
      code=params[:language].split('-')[0].strip
      Language.where(code:code).pluck(:id)[0]
    end

    def self.init_language_set
      language_table = %w(af.Afrikaans.Afrikaans ar.Arabic.العربية be.Belarusian.беларускі bg.Bulgarian.български ca.Catalan.Català cs.Czech.čeština da.Danish.dansk de.German.dansk el.Greek.ελληνικά en.English.English es.Spanish.español et.Estonian.eesti eu.Basque.Euskal fa.Farsi.فارسی fi.Finnish.suomalainen fo.Faroese.føroyskt fr.French.français ga.Irish.Gaeilge gd.Gaelic.gaélico he.Hebrew.עברית hi.Hindi.हिंदी hr.Croatian.hrvatski hu.Hungarian.magyar id.Indonesian.Indonesia is.Icelandic.Icelandic it.Italian.italiano ja.Japanese.日本の ji.Yiddish.ייִדיש ko.Korean.한국의 lt.Lithuanian.Lietuvos lv.Latvian.Latvijas mk.Macedonian.македонски ms.Malaysian.Malaysia mt.Maltese.Malti nl.Dutch.Nederlands no.Norwegian.norsk pl.Polish.polski pt.Portuguese.português ro.Romanian.român ru.Russian.русский sk.Slovak.slovenský sl.Slovenian.slovenščina sq.Albanian.shqiptar sr.Serbian.српски sv.Swedish.Svenska th.Thai.ภาษาไทย tr.Turkish.Türk uk.Ukrainian.Український ur.Urdu.اردو vi.Vietnamese.Việt zh.Chinese.中國的 zu.Zulu.Zulu)
      language_table.each {|entry|
        language=ForumAssist.named_array(entry.split('.'),[:code,:language,:local])[0]
        Language.find_or_create_by(code:language[:code]) {|entry|
          entry.name=language[:language]
          entry.local_name=language[:local]
          entry.active=false
        } }
    end
  end
end
